<?php

/**
 * Tool that displays a list and an edit panel
 *
 * @author fpvanagthoven
 */
class QuestionCreationTool {

    private $list;
    private $questionEditPanel;

    public function __construct() {
        $this->javascript();
        $this->displayList();
        $this->displayEditPanel();
    }

    private function javascript() {
        ?>
        <script type="text/javascript">
            function handleType(select)
            {
                var type = select.valueOf().value;
                clearSpecifications();
                                                                        
                /* set answerCount for options */
                document.getElementById("answerSpecifications").answerCount = 1;
                                                                        
                switch (type) {
                    case "text":
                        break;
                    case "mc":
                        addOption();
                        break;
                    case "int":
                        minMax();
                        break;
                    case "checkboxes":
                        addOption();
                        break;
                    case "scale":
                        minMaxIncr();
                        break;
                    default:
                                                                                
                        break;
                }

            }
                                                                    
            function clearSpecifications()
            {
                var specs = document.getElementById("answerSpecifications");
                specs.innerHTML = "";
                specs.clicked = null;
                specs.lastAnswer = null;
                                                        
                var questionType = document.getElementById("questionType");
                var buttons = document.getElementById("questionButtons");
                if(buttons != null)
                    questionType.removeChild(buttons);
            }
                                                                    
            function addOption()
            {                       
                var specs = document.getElementById("answerSpecifications");
                                                                        
                addAddRemoveOptionButtonsOnce(specs);
                addAnswerInput(specs);
                                                                        
            }
                                                                    
            function removeOption()
            {
                var specs = document.getElementById("answerSpecifications");
                                                                        
                if(specs.lastAnswer.prev != null)
                {
                    specs.removeChild(specs.lastAnswer);
                    specs.lastAnswer = specs.lastAnswer.prev;
                    specs.answerCount--;
                }
            }
                                                                    
            function addAnswerInput(specs)
            {
                var answerCount = specs.answerCount;
                                                                        
                /* set value for option textbox */
                var optionStr = "Option " + answerCount;
                                                                        
                /* the input textbox */
                var answerInput = document.createElement("input");
                answerInput.setAttribute("type", "text");
                answerInput.setAttribute("name", "ans" + answerCount);
                answerInput.setAttribute("value", optionStr);
                answerInput.className = "answerInput";
                                                                        
                specs.appendChild(answerInput);
                                                                        
                /* Singly linked list */
                answerInput.prev = specs.lastAnswer; // remember last one
                specs.lastAnswer = answerInput; // new lastAnswer
                                                                        
                specs.answerCount++;               
            }
                                                                    
            function addAddRemoveOptionButtonsOnce(specs)
            {
                if (specs.clicked == null)
                {
                    var buttonsDiv = document.createElement("div");
                    buttonsDiv.id = "questionButtons";
                    buttonsDiv.style.display = "inline";
                    var typeBox = document.getElementById("questionType");
                    typeBox.appendChild(buttonsDiv);
                                                            
                    addAddOptionButton(buttonsDiv);                                  
                    addRemoveOptionButton(buttonsDiv);
                                                                            
                    specs.clicked = true;
                }
            }
                                                                    
            function addAddOptionButton(buttonsDiv)
            {    
                var addOpt = document.createElement("input");
                addOpt.setAttribute("type", "button");
                addOpt.setAttribute("id", "addOpt");
                addOpt.setAttribute("class", "surveyButton");
                addOpt.setAttribute("onclick", "addOption()");
                addOpt.setAttribute("value", "Add Option");
                buttonsDiv.appendChild(addOpt);                                  
            }
                                                                    
            function addRemoveOptionButton(buttonsDiv)
            {
                var removeOpt = document.createElement("input");
                removeOpt.setAttribute("type", "button");
                removeOpt.className = "surveyButton";
                removeOpt.setAttribute("onclick", "removeOption()");
                removeOpt.setAttribute("value", "x");
                buttonsDiv.appendChild(removeOpt);
            }
                                                                   
            function minMax(min, max)
            {
                if (min == null)
                    var min = '';
                if (max == null)
                    var max = '';
                                                                                                                                                                                                                                                                                                
                var specs = document.getElementById("answerSpecifications");
                                                                                                                                                                                                                                                                                                                                                                                                                                       
                var answerDiv = document.createElement("div");
                                                                                                                                                                                                                                                                                                                                                                                                        
                answerDiv.className = "answerDiv";
                answerDiv.innerHTML = "<label for='min'>Min</label><input type='text' class='intBox' onchange='checkInt(this)' value='" + min + "' name='ans1' />" +
                    "<label for='max'>Max</label><input type='text' class='intBox' onchange='checkInt(this)' value='" + max + "' name='ans2' />";
                                                                                                                                                                                                                                                                                                                                                                                                                                   
                specs.appendChild(answerDiv);
            }      
                                            
            function checkInt(input)
            {
                input.style.borderWidth = '1px' ;
                var value = input.value;
                if (isNaN(value))
                {
                    input.style.borderColor = 'red';
                    input.checkPassed = 'no';
                }
                else
                {
                    input.style.border = '1px solid #888;';
                    input.checkPassed = null;
                }
            }
                            
            function minMaxIncr(left, right, incr)
            {
                if (left == null)
                    var left = '';
                else
                    left.replace("'", "&#39;");
                if (right == null)
                    var right = '';
                else
                    right.replace("'", "&#39;");
                if (incr == null)
                    var incr = '';
                                                                                                                                                                                                                        
                var specs = document.getElementById("answerSpecifications");
                                                                                                                                                                                                                                                                                                                                                                                                               
                var answerDiv = document.createElement("div");
                answerDiv.className = "answerDiv";
                                                                                                                                               
                var leftLabel = document.createElement("label");
                var rightLabel = document.createElement("label");
                var scaleLabel = document.createElement("label");
                leftLabel.innerHTML = "Left label";
                rightLabel.innerHTML = "Right label";
                scaleLabel.innerHTML = "Scale count";
                                                                                                                                                
                var leftInput = document.createElement("input");
                leftInput.type = "text";
                leftInput.value = left;
                leftInput.name= "ans1";
                leftInput.setAttribute("onchange", "handleAnswerChange()");
                                                                                                                                                
                var rightInput = document.createElement("input");
                rightInput.type = "text";
                rightInput.value = right;
                rightInput.name = "ans2";
                rightInput.setAttribute("onchange", "handleAnswerChange()");
                                                                                                                                                
                var scaleInput = document.createElement("input");
                scaleInput.type = "text";
                scaleInput.className = "intBox";
                scaleInput.value = incr;
                scaleInput.setAttribute("onblur", "checkInt(this)");
                scaleInput.setAttribute("onchange", "");
                scaleInput.name = "ans3";
                                                                                                                                                
                answerDiv.appendChild(leftLabel);
                answerDiv.appendChild(leftInput);
                answerDiv.appendChild(rightLabel);
                answerDiv.appendChild(rightInput);
                answerDiv.appendChild(scaleLabel);
                answerDiv.appendChild(scaleInput);
                                                                                                                                                                                                                                                                                                                                                                                           
                specs.appendChild(answerDiv);
            }   
            
            function newCategory()
            {
                var categoryBox = document.getElementById("categoryBox");
                categoryBox.innerHTML = "";
                
                var categoryInput = document.createElement("input");
                categoryInput.name = "questionCategory";
                
                categoryBox.appendChild(categoryInput);
            }
                       
            function clearFields()
            {
                clearCategory();
                clearCode();
                clearTitle();
                clearDescription();
                clearType();
            }
            
            function clearCategory()
            {
                var categoryBox = document.getElementById("categoryBox");
                categoryBox.innerHTML = "";
                
                var questionCategorySelect = document.createElement("select");
                questionCategorySelect.setAttribute("name", "questionCategory");
                questionCategorySelect.id = "questionCategorySelect";
                
                var newCategoryButton = document.createElement("input");
                newCategoryButton.setAttribute("type", "button");
                newCategoryButton.setAttribute("onclick", "newCategory()");
                newCategoryButton.setAttribute("value", "New Category");
                newCategoryButton.className = "surveyButton";
                
                categoryBox.appendChild(questionCategorySelect);
                categoryBox.appendChild(newCategoryButton);
            }
            
            function clearCode()
            {
                var codeInput = document.getElementById("questionCode");
                codeInput.value = "";
            }
            
            function clearTitle()
            {
                var titleInput = document.getElementById("questionTitle");
                titleInput.value ="";
            }
            
            function clearDescription()
            {
                var descriptionInput = document.getElementById("questionDescription");
                descriptionInput.value = "";
            }
            
            function clearType()
            {
                var typeSelect = document.getElementById("questionTypeSelect");
                typeSelect.selectedIndex = 0;
            }
            
        </script>
        <?php
    }

    private function displayList() {
        ?>
        <div id="questionListWrapper">
            <select id="questionsList" size="9999">
            </select>
        </div>
        <?php
    }

    private function displayEditPanel() {
        ?>
        <div id="questionCreation" class="floatLeft">
            <?php $this->displayForm(); ?>
        </div>
        <?php
    }

    private function displayForm() {
        ?>
        <form id="questionEditForm" method="post" action="" onsubmit="">
            <table class="questionTable">
                <tr>
                    <td><label for="questionCategory">Category</label></td>
                    <td id="categoryBox"><!-- Select should be filled with existing categories-->
                        <select id="questionCategorySelect" name="questionCategory">
                            <option value='Test Category'>Test Category</option>
                        </select>
                        <!-- New category button -->
                        <input type="button" class="surveyButton" onclick="newCategory()" value="New Category" />
                    </td>
                </tr>
                <tr>
                    <td><label for="questionCode">Code</label></td>
                    <td><input id="questionCode" name="questionCode" size="5" /></td>
                </tr>
                <tr>
                    <td><label for="questionTitle">Title</label></td>
                    <td><input id="questionTitle" name="questionTitle" size="60" /></td>
                </tr>
                <tr>
                    <td><label for="questionDescription">Description</label></td>
                    <td><input id="questionDescription" name="questionDescription" size="60" /></td>
                </tr>
                <tr>
                    <td><label for="questionType">Type answer</label></td>
                    <td id="questionType">
                        <select id="questionTypeSelect" name="questionType" onchange="handleType(this)">
                            <option value='text' selected='selected'>Text</option>
                            <option value='int'>Integer</option>
                            <option value='mc'>Multiple choice</option>
                            <option value='checkboxes'>Checkboxes</option>
                            <option value='scale'>Scale</option>
                        </select>
                    </td>
                </tr>
            </table>
            <div id="answerSpecifications"></div>
            <input id="clearQuestionFields" type="button" onclick="clearFields()" class="surveyButton" value="Clear" />
            <input id="saveQuestion" type="submit" class="surveyButton" value="Save" />
        </form>
        <?php
    }

}
?>
